/**
 * @file snow_effect.h
 */

#ifndef _SNOW_EFFECT
#define _SNOW_EFFECT

#include "vector.h"
#include "particle_system.h"
#include "material.h"
#include "vector2D.h"

#include "weather_effect.h"

class SpriteParticles;
class PlaneEmitter;

class SnowEffect : public WeatherEffect
{
  public:
    SnowEffect(const TiXmlElement* root = NULL);
    virtual ~SnowEffect();

    virtual void loadParams(const TiXmlElement* root);

    virtual bool init();

    virtual bool activate();
    virtual bool deactivate();

    virtual void draw() const;
    virtual void tick(float dt);

    void activateSnow();
    void deactivateSnow();
    
  private:
    void numParticles(int n);
    void materialTexture(const std::string& texture);
    void lifeSpan(float lifeSpan, float randomLifeSpan);
    void radius(float radius, float randomRadius);
    void mass(float mass, float randomMass);
    void emissionRate(float emissionRate);
    void emissionVelocity(float velocity, float randomVelocity);
    void spread(float angle, float randomAngle);
    void size(float sizeX, float sizeY);
    void coord(float xCoor, float yCoor, float zCoor);
    
    int particles;
    std::string texture;
    float life, randomLife;
    float snowRadius, randomRadius;
    float snowMass, randomMass;
    float rate;
    float velocity, randomVelocity;
    float angle, randomAngle;
    Vector snowCoord;
    Vector2D snowSize;

    static SpriteParticles* snowParticles;
    
    PlaneEmitter*          emitter;
};


#endif  /* _SNOW_EFFECT */
